<?xml version="1.0"?>
<!-- in case of any change in xsl/xml file modify all connected xsl and xml files from this package  -->

<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://icl.com/saxon" xmlns:graph="graph" xmlns:results="results" extension-element-prefixes="saxon">

    <!-- =================  print build errors menu ============================ -->
    
    <xsl:template name="display_build_errors_menu">
    
    <xsl:if test="($setup_problems) > 0">
    <xsl:if test="($codereview) > 0">
        <xsl:call-template name="display_linked_menu_item">
        <xsl:with-param name="text" select="$RES_PARAMETER_BUILD_ERRORS" />
        <xsl:with-param name="link" select="'#berr'" />
        </xsl:call-template>
   	</xsl:if> 
    </xsl:if>
    
    </xsl:template>

    <!-- =================  print build errors ============================ -->
    
    <xsl:template name="display_build_errors">
    
    <xsl:if test="($setup_problems) > 0">
    <br/>
    <xsl:call-template name="build_errors_header"/>
    <br/>    
    <xsl:call-template name="print_header_separator"/>
    
    <xsl:call-template name="testing_process_problems"/>
    <br/>    
    </xsl:if>

    </xsl:template>    
    
    <!-- =================  print build errors header ============================ -->
    
    <xsl:template name="build_errors_header">
        <a name="berr"/>
        <table width="{$width}" cellpadding="0" cellspacing="0">
            <xsl:if test="($report_format_mode='pdf')">
               <xsl:attribute name="cols">100%</xsl:attribute>
            </xsl:if>
            <tr>
               <xsl:if test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">
                  <td width="25%"></td>
               </xsl:if>
               <td align="center">
                   <div class="small_header"><xsl:value-of select="$RES_PARAMETER_BUILD_ERRORS"/></div>
               </td>
               <xsl:if test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">
                  <td align="right" width="25%" valign="bottom">
                  <xsl:if test="($first_back_to_top = 'false')">
                    <xsl:call-template name="back_to_top"/>
                  </xsl:if>
                  <saxon:assign name="first_back_to_top">false</saxon:assign>
                  </td>
               </xsl:if>
            </tr>
        </table>
    </xsl:template>
   
    <!-- =================  testing process problems  ============================ -->
    
    <xsl:template name="testing_process_problems">
    <table width="{$width}" cellpadding='0' cellspacing='0' class="doubleborder" border="0" bordercolor="{$cs_bdrcolor}">
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>    
    <xsl:variable name="errors_count" select="0" saxon:assignable="yes"/>
    <xsl:variable name="problem_errors_count" select="0" saxon:assignable="yes"/>
    <xsl:variable name="tmp_msg" select="''" saxon:assignable="yes"/>
    <xsl:variable name="tmp_type" select="''" saxon:assignable="yes"/>
    <xsl:variable name="tmp_error" select="''" saxon:assignable="yes"/>		    
    
    <saxon:assign name="isFirstRow">true</saxon:assign>

    <xsl:for-each select="/ResultsSession/SetupProblems/Problem">
    <xsl:sort select="@sev" order="descending" />
    <xsl:sort select="@type"/>
    <xsl:sort select="@msg"/>
	    
	    <xsl:if test="(($errors_count) &lt; ($report.setup.problems.display_limit))">
	        <xsl:if test="not($tmp_msg = @msg) or not($tmp_type = @type)">
	            <saxon:assign name="tmp_msg" select="@msg"/>
     	        <saxon:assign name="tmp_type" select="@type"/>

                <xsl:variable name="rowStyle" saxon:assignable="yes">tree</xsl:variable>
     	        <!--xsl:if test="$isFirstRow = 'true'">
                    <saxon:assign name="rowStyle">root</saxon:assign>
                    <saxon:assign name="isFirstRow" select="false"/>
                </xsl:if -->

			    <tr>
			    <td align="left" style="padding-left:10px" class="{$rowStyle}"><b>
                <xsl:if test="(@sev = 0)">
                   [INFO]
                   </xsl:if>
                   <xsl:if test="(@sev = 1)">
                   [WARNING]
                   </xsl:if>
                   <xsl:if test="(@sev = 2)">
                   [ERROR]
                </xsl:if>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
			    <xsl:value-of select="(@msg)"/></b>
			    </td>
			    </tr>
                <saxon:assign name="problem_errors_count" select="0"/>
            <tr><td align="left" style="padding-top:5px;padding-bottom:5px" class="tree">
    	    <table width="100%" border="0" cellpadding="0" cellspacing="0">
            <xsl:if test="($report_format_mode='pdf')">
               <xsl:attribute name="cols">100%</xsl:attribute>
            </xsl:if>
		        <xsl:for-each select="./ErrorList/Error">
                <xsl:sort select="@val"/>
                   <xsl:if test="not($tmp_error = @val)">
        	          <saxon:assign name="tmp_error" select="@val"/>
                      <tr><td><pre class="tree" style="margin:5px 5px 3px 5px;white-space:pre-wrap;"><xsl:value-of select="(@val)"/></pre></td></tr>
                      <saxon:assign name="errors_count" select="$errors_count + 1"/>
                      <saxon:assign name="problem_errors_count" select="$problem_errors_count + 1"/>
                </xsl:if>
            </xsl:for-each>
                <xsl:if test="(($problem_errors_count) &lt; (@totErrs)) and (($errors_count) &lt; ($report.setup.problems.display_limit))">
                
                      <tr><td><pre style="margin:5px 5px 3px 5px;white-space:pre-wrap;"><xsl:value-of select="$RES_PARAMETER_ELLIPSIS"/></pre></td></tr>
                </xsl:if>
            </table>
            </td></tr>
     	        <saxon:assign name="tmp_error" select="''"/>
	        </xsl:if>
	    </xsl:if>
    
    </xsl:for-each>
    
    <xsl:if test="not(($errors_count) &lt; ($report.setup.problems.display_limit))">
    <tr><td><pre style="margin:5px 5px 3px 5px;white-space:pre-wrap;"><xsl:value-of select="$RES_PARAMETER_ELLIPSIS"/></pre></td></tr>
    </xsl:if>
    </table>
    </xsl:template>
    
</xsl:stylesheet>
